==> mongodb-7.0.23.gh.tar.gz: mongo-r7.0.23/src/mongo/db/catalog/database_holder.cpp <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/platform/basic.h"

#include "mongo/db/catalog/database_holder.h"

namespace mongo {

namespace {

const auto getDatabaseHolderFromServiceContext =
    ServiceContext::declareDecoration<std::unique_ptr<DatabaseHolder>>();

}  // namespace

DatabaseHolder* DatabaseHolder::get(ServiceContext* service) {
    return getDatabaseHolderFromServiceContext(service).get();
}

DatabaseHolder* DatabaseHolder::get(ServiceContext& service) {
    return getDatabaseHolderFromServiceContext(service).get();
}

DatabaseHolder* DatabaseHolder::get(OperationContext* opCtx) {
    return get(opCtx->getServiceContext());
}

void DatabaseHolder::set(ServiceContext* service, std::unique_ptr<DatabaseHolder> databaseHolder) {
    auto& holder = getDatabaseHolderFromServiceContext(service);
    holder = std::move(databaseHolder);
}

}  // namespace mongo

==> mongodb-8.0.12.gh.tar.gz: mongo-r8.0.12/src/mongo/db/catalog/database_holder.cpp <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include <utility>

#include "mongo/db/catalog/database_holder.h"
#include "mongo/util/decorable.h"

namespace mongo {

namespace {

const auto getDatabaseHolderFromServiceContext =
    ServiceContext::declareDecoration<std::unique_ptr<DatabaseHolder>>();

}  // namespace

DatabaseHolder* DatabaseHolder::get(ServiceContext* service) {
    return getDatabaseHolderFromServiceContext(service).get();
}

DatabaseHolder* DatabaseHolder::get(ServiceContext& service) {
    return getDatabaseHolderFromServiceContext(service).get();
}

DatabaseHolder* DatabaseHolder::get(OperationContext* opCtx) {
    return get(opCtx->getServiceContext());
}

void DatabaseHolder::set(ServiceContext* service, std::unique_ptr<DatabaseHolder> databaseHolder) {
    auto& holder = getDatabaseHolderFromServiceContext(service);
    holder = std::move(databaseHolder);
}

}  // namespace mongo
